@@ -6,7 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.19';
 
 use Statistics::Covid::Utils;
 
@@ -142,7 +142,7 @@ sub	fetch {
 	my $jar = HTTP::CookieJar::LWP->new;
 	my $ua = LWP::UserAgent->new(
 		cookie_jar => $jar,
-		timeout => 10
+		timeout => 50, # seconds
 	);
 	# the return array will be [url, perlvar] for each url
 	my @retJsonPerlVars = ();
